@@ -5,12 +5,12 @@ try:
 except ImportError:
     from UserList import UserList
 
-from attrdict import AttrDict
+from qbittorrentapi._attrdict import AttrDict
 
 
 class APINames(Enum):
     """
-    API names for API endpoints
+    API namespaces for API endpoints
 
     e.g 'torrents' in http://localhost:8080/api/v2/torrents/addTrackers
     """
